package com.example.shmelevmvmobile.viewmodel

import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.shmelevmvmobile.API.Repository
import com.example.shmelevmvmobile.API.Result.Success
import com.example.shmelevmvmobile.API.Result.Error
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.channels.Channel
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.receiveAsFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch

class ViewModelMain(private val repository: Repository): ViewModel() {
    private val _showErrorToastChannel = Channel<Boolean>()
    val showErrorToastChannel = _showErrorToastChannel.receiveAsFlow()
    var codeIsCorrect by mutableStateOf(false)

    fun sendCodeToEmail(email:String)
    {
        viewModelScope.launch {
            repository.sendCodeEmail(email).collect{
                when(it) {
                    is Error -> {
                        _showErrorToastChannel.send(true)
                    }
                    is Success -> {
                        _showErrorToastChannel.send(false)
                    }
                }
            }
        }
    }
    fun SignIn(email: String, code: String) {
        viewModelScope.launch {
            repository.signInCode(email, code).collect {
                when (it) {
                    is Error -> {
                        codeIsCorrect = false
                    }
                    is Success -> {
                        codeIsCorrect = true
                    }
                }
            }
        }
    }
}